@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use feature 'fc';
 
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.01'; # VERSION
 
 use mro        ();
 use IO::File   ();
@@ -67,8 +67,8 @@ sub import {
 
     eval {
         feature->import($_) for (@features);
-        feature->import( map { @{ $experiments{$_} } } grep { $_ <= $perl_version } keys %experiments )
-            unless ( grep { $_ eq 'noexperiments' } @functions );
+        my @experiments = map { @{ $experiments{$_} } } grep { $_ <= $perl_version } keys %experiments;
+        feature->import(@experiments) unless ( not @experiments or grep { $_ eq 'noexperiments' } @functions );
     };
     if ( my $err = $@ ) {
         $err =~ s/\s*at .+? line \d+\.\s+//;
@@ -92,7 +92,7 @@ exact - Perl pseudo pragma to enable strict, warnings, features, mro, filehandle
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/exact.svg)](https://travis-ci.org/gryphonshafer/exact)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/exact/badge.png)](https://coveralls.io/r/gryphonshafer/exact)
